function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { DestinationPlugin, PluginType, SegmentError, ErrorType } from '@segment/analytics-react-native';
import appsFlyer from 'react-native-appsflyer';
import identify from './methods/identify';
import track from './methods/track';
export class AppsflyerPlugin extends DestinationPlugin {
  constructor() {
    super(...arguments);

    _defineProperty(this, "type", PluginType.destination);

    _defineProperty(this, "key", 'AppsFlyer');

    _defineProperty(this, "settings", null);

    _defineProperty(this, "hasRegisteredInstallCallback", false);

    _defineProperty(this, "hasRegisteredDeepLinkCallback", false);

    _defineProperty(this, "hasInitialized", false);

    _defineProperty(this, "registerConversionCallback", () => {
      appsFlyer.onInstallConversionData(res => {
        const {
          af_status,
          media_source,
          campaign,
          is_first_launch
        } = res === null || res === void 0 ? void 0 : res.data;
        const properties = {
          provider: this.key,
          campaign: {
            source: media_source,
            name: campaign
          }
        };

        if (is_first_launch && JSON.parse(is_first_launch) === true) {
          if (af_status === 'Non-organic') {
            var _this$analytics;

            void ((_this$analytics = this.analytics) === null || _this$analytics === void 0 ? void 0 : _this$analytics.track('Install Attributed', properties));
          } else {
            var _this$analytics2;

            void ((_this$analytics2 = this.analytics) === null || _this$analytics2 === void 0 ? void 0 : _this$analytics2.track('Organic Install', {
              provider: 'AppsFlyer'
            }));
          }
        }
      });
    });

    _defineProperty(this, "registerDeepLinkCallback", () => {
      appsFlyer.onAppOpenAttribution(res => {
        if ((res === null || res === void 0 ? void 0 : res.status) === 'success') {
          var _this$analytics3;

          const {
            campaign,
            media_source
          } = res.data;
          const properties = {
            provider: this.key,
            campaign: {
              name: campaign,
              source: media_source
            }
          };
          void ((_this$analytics3 = this.analytics) === null || _this$analytics3 === void 0 ? void 0 : _this$analytics3.track('Deep Link Opened', properties));
        }
      });
    });

    _defineProperty(this, "registerUnifiedDeepLinkCallback", () => {
      appsFlyer.onDeepLink(res => {
        if (res.deepLinkStatus !== 'NOT_FOUND') {
          var _this$analytics4;

          const {
            DLValue,
            media_source,
            campaign
          } = res.data;
          const properties = {
            deepLink: DLValue,
            campaign: {
              name: campaign,
              source: media_source
            }
          };
          void ((_this$analytics4 = this.analytics) === null || _this$analytics4 === void 0 ? void 0 : _this$analytics4.track('Deep Link Opened', properties));
        }
      });
    });
  }

  async update(settings, _) {
    var _this$analytics5;

    const defaultOpts = {
      isDebug: false,
      timeToWaitForATTUserAuthorization: 60,
      onInstallConversionDataListener: true
    };
    const appsflyerSettings = settings.integrations[this.key];

    if (appsflyerSettings === undefined) {
      return;
    }

    const clientConfig = (_this$analytics5 = this.analytics) === null || _this$analytics5 === void 0 ? void 0 : _this$analytics5.getConfig();
    this.settings = appsflyerSettings;

    if (this.settings.trackAttributionData && !this.hasRegisteredInstallCallback) {
      this.registerConversionCallback();
      this.hasRegisteredInstallCallback = true;
    }

    if ((clientConfig === null || clientConfig === void 0 ? void 0 : clientConfig.trackDeepLinks) === true && !this.hasRegisteredDeepLinkCallback) {
      this.registerDeepLinkCallback();
      this.registerUnifiedDeepLinkCallback();
      this.hasRegisteredDeepLinkCallback = true;
    }

    if (!this.hasInitialized) {
      try {
        await appsFlyer.initSdk({
          devKey: this.settings.appsFlyerDevKey,
          appId: this.settings.appleAppID,
          onDeepLinkListener: (clientConfig === null || clientConfig === void 0 ? void 0 : clientConfig.trackDeepLinks) === true,
          ...defaultOpts
        });
        this.hasInitialized = true;
      } catch (error) {
        var _this$analytics6, _this$analytics7;

        const message = 'AppsFlyer failed to initialize';
        (_this$analytics6 = this.analytics) === null || _this$analytics6 === void 0 ? void 0 : _this$analytics6.reportInternalError(new SegmentError(ErrorType.PluginError, message, error));
        (_this$analytics7 = this.analytics) === null || _this$analytics7 === void 0 ? void 0 : _this$analytics7.logger.warn(`${message}: ${JSON.stringify(error)}`);
      }
    }
  }

  identify(event) {
    identify(event);
    return event;
  }

  async track(event) {
    await track(event);
    return event;
  }

}
//# sourceMappingURL=AppsflyerPlugin.js.map